==> koha-3.22.02.tar.gz: koha-3.22.02/installer/data/mysql/uk-UA/optional/sample_news.sql <==
INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Добро пожаловать в Коха','Добро пожаловать в Коха. Коха является полнофункциональной АБИС с открытыми исходниками. Разработана первоначально в Новой Зеландии компанией Katipo Communications Ltd и впервые выпущена в январе 2000 года для библиотечного консорциума Хороунеа, Коха в настоящее время поддерживается группой поставщиков программного обеспечения и специалистами по библиотечным технологиям со всего земного шара. ','ru-RU','2007-10-29 05:25:58','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('What\'s Next?','Now that you\'ve installed Koha, what\'s next? Here are some suggestions:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Read Koha Documentation</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Read/Write to the Koha Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Read and Contribute to Discussions</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Report Koha Bugs</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\">Submit Patches to Koha using Git (Version Control System)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Chat with Koha users and developers</a></li>\r\n</ul>\r\n','en','2007-10-29 05:34:45','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Welcome to Koha','Welcome to Koha. Koha is a full-featured open-source ILS. Developed initially in New Zealand by Katipo Communications Ltd and first deployed in January of 2000 for Horowhenua Library Trust, Koha is currently maintained by a team of software providers and library technology staff from around the globe.','en','2008-05-28 22:45:42','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Ласкаво просимо до Коха','Ласкаво просимо до Коха. Коха є повнофункціональною АБІС з відкритими джерельними кодам. Розроблена спочатку в Новій Зеландії компанією Katipo Communications Ltd і вперше випущена в січні 2000 року для бібліотечного консорціуму Хороунеа. Коха в даний час підтримується групою постачальників програмного забезпечення і фахівцями з бібліотечних технологій зі всієї земної кулі. ','koha','2008-05-28 22:48:29','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Что дальше?','Теперь, когда Вы установили Коха, что же дальше? Вот некоторые предложения:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацию про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишите на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\"> Читайте и принимайте участие в обсуждениях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Отитывайтесь про недочеты Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчи для Коха, используя Git (система контроля версий)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат пользователей и разработчиков Коха</a></li>\r\n</ul>','ru-RU','2008-05-28 23:02:25','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Що далі?','Тепер, коли Ви встановили Коха, що ж далі? Ось деякі пропозиції:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацію про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишіть на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Читайте і беріть участь в обговореннях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Рапортуйте про недоліки Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчі для Коха, використовуючи Git (система контролю версій)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат користувачів та розробників Коха</a></li>\r\n</ul>','koha','2008-05-28 23:07:23','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Ласкаво просимо до Коха','Ласкаво просимо до Коха. Коха є повнофункціональною АБІС з відкритими джерельними кодам. Розроблена спочатку в Новій Зеландії компанією Katipo Communications Ltd і вперше випущена в січні 2000 року для бібліотечного консорціуму Хороунеа. Коха в даний час підтримується групою постачальників програмного забезпечення і фахівцями з бібліотечних технологій зі всієї земної кулі. ','uk-UA','2008-05-28 22:48:29','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `new`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Що далі?','Тепер, коли Ви встановили Коха, що ж далі? Ось деякі пропозиції:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацію про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишіть на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Читайте і беріть участь в обговореннях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Рапортуйте про недоліки Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчі для Коха, використовуючи Git (система контролю версій)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат користувачів та розробників Коха</a></li>\r\n</ul>','uk-UA','2008-05-28 23:07:23','2099-01-10',2);

==> koha-17.05.04.tar.gz: koha-17.05.04/installer/data/mysql/uk-UA/optional/sample_news.sql <==
INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Добро пожаловать в Коха','Добро пожаловать в Коха. Коха является полнофункциональной АБИС с открытыми исходниками. Разработана первоначально в Новой Зеландии компанией Katipo Communications Ltd и впервые выпущена в январе 2000 года для библиотечного консорциума Хороунеа, Коха в настоящее время поддерживается группой поставщиков программного обеспечения и специалистами по библиотечным технологиям со всего земного шара. ','ru-RU','2007-10-29 05:25:58','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('What\'s Next?','Now that you\'ve installed Koha, what\'s next? Here are some suggestions:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Read Koha Documentation</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Read/Write to the Koha Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Read and Contribute to Discussions</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Report Koha Bugs</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\">Submit Patches to Koha using Git (Version Control System)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Chat with Koha users and developers</a></li>\r\n</ul>\r\n','en','2007-10-29 05:34:45','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Welcome to Koha','Welcome to Koha. Koha is a full-featured open-source ILS. Developed initially in New Zealand by Katipo Communications Ltd and first deployed in January of 2000 for Horowhenua Library Trust, Koha is currently maintained by a team of software providers and library technology staff from around the globe.','en','2008-05-28 22:45:42','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Ласкаво просимо до Коха','Ласкаво просимо до Коха. Коха є повнофункціональною АБІС з відкритими джерельними кодам. Розроблена спочатку в Новій Зеландії компанією Katipo Communications Ltd і вперше випущена в січні 2000 року для бібліотечного консорціуму Хороунеа. Коха в даний час підтримується групою постачальників програмного забезпечення і фахівцями з бібліотечних технологій зі всієї земної кулі. ','koha','2008-05-28 22:48:29','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Что дальше?','Теперь, когда Вы установили Коха, что же дальше? Вот некоторые предложения:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацию про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишите на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\"> Читайте и принимайте участие в обсуждениях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Отитывайтесь про недочеты Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчи для Коха, используя Git (система контроля версий)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат пользователей и разработчиков Коха</a></li>\r\n</ul>','ru-RU','2008-05-28 23:02:25','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Що далі?','Тепер, коли Ви встановили Коха, що ж далі? Ось деякі пропозиції:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацію про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишіть на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Читайте і беріть участь в обговореннях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Рапортуйте про недоліки Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчі для Коха, використовуючи Git (система контролю версій)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат користувачів та розробників Коха</a></li>\r\n</ul>','koha','2008-05-28 23:07:23','2099-01-10',2);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Ласкаво просимо до Коха','Ласкаво просимо до Коха. Коха є повнофункціональною АБІС з відкритими джерельними кодам. Розроблена спочатку в Новій Зеландії компанією Katipo Communications Ltd і вперше випущена в січні 2000 року для бібліотечного консорціуму Хороунеа. Коха в даний час підтримується групою постачальників програмного забезпечення і фахівцями з бібліотечних технологій зі всієї земної кулі. ','uk-UA','2008-05-28 22:48:29','2099-01-10',1);

INSERT INTO `opac_news` (`title`, `content`, `lang`, `timestamp`, `expirationdate`, `number`) VALUES
('Що далі?','Тепер, коли Ви встановили Коха, що ж далі? Ось деякі пропозиції:\r\n<ul>\r\n<li><a href=\"http://koha-community.org/documentation/\">Читайте документацію про Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org\">Читайте/пишіть на Коха Wiki</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Читайте і беріть участь в обговореннях</a></li>\r\n<li><a href=\"http://bugs.koha-community.org\">Рапортуйте про недоліки Коха</a></li>\r\n<li><a href=\"http://wiki.koha-community.org/wiki/Version_Control_Using_Git\"> Подавайте патчі для Коха, використовуючи Git (система контролю версій)</a></li>\r\n<li><a href=\"http://koha-community.org/support/\">Чат користувачів та розробників Коха</a></li>\r\n</ul>','uk-UA','2008-05-28 23:07:23','2099-01-10',2);
